==> 0.1.64.tar.gz: lib/widgets/widget_overlay_actions.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:oowoo_core/oowoo_core.dart';

enum GestureType { rightClick, onTap, longPress }

class WidgetOverlayActions extends StatefulWidget {
  final Widget Function(Widget child)? backgroundBuilder;
  final Widget Function(Widget child, Size size, Offset childPosition,
      Offset? rightClickPosition, double animationValue, Function hide) builder;
  final Widget child;
  final Duration duration;
  final GestureType gestureType;
  const WidgetOverlayActions({
    Key? key,
    this.duration = const Duration(milliseconds: 200),
    this.gestureType = GestureType.onTap,
    this.backgroundBuilder,
    required this.builder,
    required this.child,
  }) : super(key: key);

  @override
  State<WidgetOverlayActions> createState() => WidgetOverlayActionsState();
}

class WidgetOverlayActionsState extends State<WidgetOverlayActions>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  GlobalKey dropdownKey = GlobalKey();
  OverlayEntry? floatingDropdown;
  bool isDropdownOpened = false;
  Offset? rightClickPosition;

  void _hideMenu() async {
    await animationController.reverse();
    floatingDropdown?.remove();
    isDropdownOpened = !isDropdownOpened;
  }

  @override
  void initState() {
    super.initState();
    animationController = AnimationController(
      vsync: this,
      lowerBound: .0001,
      upperBound: 1,
      duration: widget.duration,
      reverseDuration: widget.duration,
    );
  }

  OverlayEntry _createFloatingDropdown() {
    animationController.forward();
    RenderBox box =
        dropdownKey.currentContext!.findRenderObject()! as RenderBox;
    Offset position = box.localToGlobal(Offset.zero);
    Widget child = Stack(
      children: [
        AnimatedBuilder(
          animation: animationController,
          builder: (_, child) {
            return widget.builder(widget.child, box.size, position,
                rightClickPosition, animationController.value, _hideMenu);
          },
        ),
      ],
    );
    return OverlayEntry(
      builder: (context) {
        return GestureDetector(
          onTap: _hideMenu,
          child: Material(
            color: Colors.transparent,
            child: widget.backgroundBuilder != null
                ? widget.backgroundBuilder!(child)
                : Container(
                    width: Get.width,
                    height: Get.height,
                    color: Colors.transparent,
                    child: child,
                  ),
          ),
        );
      },
    );
  }

  onTap() {
    FocusManager.instance.primaryFocus?.unfocus();
    setState(() {
      if (!isDropdownOpened) {
        floatingDropdown = _createFloatingDropdown();
        Overlay.of(context)?.insert(floatingDropdown!);
        isDropdownOpened = !isDropdownOpened;
      }
    });
    oowooHaptic();
  }

  @override
  Widget build(BuildContext context) {
    switch (widget.gestureType) {
      case GestureType.rightClick:
        return Listener(
          child: Container(key: dropdownKey, child: widget.child),
          onPointerDown: (PointerDownEvent event) async {
            if (event.kind == PointerDeviceKind.mouse &&
                event.buttons == kSecondaryMouseButton) {
              rightClickPosition = event.position;
              setState(() {
                if (isDropdownOpened) {
                  floatingDropdown = _createFloatingDropdown();
                  Overlay.of(context)?.insert(floatingDropdown!);
                  isDropdownOpened = !isDropdownOpened;
                }
              });
            }
          },
        );
      case GestureType.longPress:
        return GestureDetector(
          key: dropdownKey,
          onLongPress: onTap,
          child: widget.child,
        );
      default:
        return GestureDetector(
          key: dropdownKey,
          onTap: onTap,
          child: widget.child,
        );
    }
  }
}

==> 0.2.9.tar.gz: lib/widgets/widget_overlay_actions.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:oowoo_core/oowoo_core.dart';

enum GestureType { rightClick, onTap, longPress }

class WidgetOverlayActions extends StatefulWidget {
  final Widget Function(Widget child)? backgroundBuilder;
  final Widget Function(Widget child, Size size, Offset childPosition,
      Offset? rightClickPosition, double animationValue, Function hide) builder;
  final Widget child;
  final Duration duration;
  final GestureType gestureType;
  const WidgetOverlayActions({
    Key? key,
    this.duration = const Duration(milliseconds: 200),
    this.gestureType = GestureType.onTap,
    this.backgroundBuilder,
    required this.builder,
    required this.child,
  }) : super(key: key);

  @override
  State<WidgetOverlayActions> createState() => WidgetOverlayActionsState();
}

class WidgetOverlayActionsState extends State<WidgetOverlayActions>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  GlobalKey dropdownKey = GlobalKey();
  OverlayEntry? floatingDropdown;
  bool isDropdownOpened = false;
  Offset? rightClickPosition;

  void hideMenu() async {
    await animationController.reverse();
    floatingDropdown?.remove();
    isDropdownOpened = !isDropdownOpened;
  }

  @override
  void initState() {
    super.initState();
    animationController = AnimationController(
      vsync: this,
      lowerBound: .0001,
      upperBound: 1,
      duration: widget.duration,
      reverseDuration: widget.duration,
    );
  }

  OverlayEntry _createFloatingDropdown() {
    animationController.forward();
    RenderBox box =
        dropdownKey.currentContext!.findRenderObject()! as RenderBox;
    Offset position = box.localToGlobal(Offset.zero);
    Widget child = Stack(
      children: [
        AnimatedBuilder(
          animation: animationController,
          builder: (_, child) {
            return widget.builder(widget.child, box.size, position,
                rightClickPosition, animationController.value, hideMenu);
          },
        ),
      ],
    );
    return OverlayEntry(
      builder: (context) {
        return GestureDetector(
          onTap: hideMenu,
          child: Material(
            color: Colors.transparent,
            child: widget.backgroundBuilder != null
                ? widget.backgroundBuilder!(child)
                : Container(
                    width: Get.width,
                    height: Get.height,
                    color: Colors.transparent,
                    child: child,
                  ),
          ),
        );
      },
    );
  }

  onTap() {
    FocusManager.instance.primaryFocus?.unfocus();
    setState(() {
      if (!isDropdownOpened) {
        floatingDropdown = _createFloatingDropdown();
        Overlay.of(context)?.insert(floatingDropdown!);
        isDropdownOpened = !isDropdownOpened;
      }
    });
    oowooHaptic();
  }

  @override
  Widget build(BuildContext context) {
    switch (widget.gestureType) {
      case GestureType.rightClick:
        return Listener(
          child: Container(key: dropdownKey, child: widget.child),
          onPointerDown: (PointerDownEvent event) async {
            if (event.kind == PointerDeviceKind.mouse &&
                event.buttons == kSecondaryMouseButton) {
              rightClickPosition = event.position;
              setState(() {
                if (isDropdownOpened) {
                  floatingDropdown = _createFloatingDropdown();
                  Overlay.of(context)?.insert(floatingDropdown!);
                  isDropdownOpened = !isDropdownOpened;
                }
              });
            }
          },
        );
      case GestureType.longPress:
        return GestureDetector(
          key: dropdownKey,
          onLongPress: onTap,
          child: widget.child,
        );
      default:
        return GestureDetector(
          key: dropdownKey,
          onTap: onTap,
          child: widget.child,
        );
    }
  }
}
